@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: cobalt.h 58 2004-04-30 13:15:13Z pdh $
+ * $Id: cobalt.h 131 2004-11-21 10:42:50Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -9,6 +9,8 @@
 #ifndef _COBALT_H_
 #define _COBALT_H_
 
+/* #define PCI_SERIAL				1 */
+
 #define BAUD_RATE						115200
 
 #define LED_QUBE_LEFT				(1 << 0)
@@ -24,6 +26,13 @@
 #define BUTTON_ENTER					(1 << 6)
 #define BUTTON_SELECT				(1 << 7)
 
+#define BUTTON_MASK					(BUTTON_CLEAR | \
+											BUTTON_LEFT | \
+											BUTTON_UP | \
+											BUTTON_DOWN | \
+											BUTTON_RIGHT | \
+											BUTTON_ENTER | \
+											BUTTON_SELECT)
 #endif
 
 /* vi:set ts=3 sw=3 cin path=include,../include: */
