@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: pci.h 4 2004-03-28 16:06:07Z pdh $
+ * $Id: pci.h 130 2004-11-18 21:59:09Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -11,6 +11,9 @@
 
 #define PCI_CLOCK								(33 * 1000000)
 
+#define PCI_DEV_SLOT							10
+#define PCI_FNC_SLOT							0
+
 #define PCI_DEV_GALILEO						0
 #define PCI_FNC_GALILEO						0
 
